==> 0.3.140.tar.gz: lib/pickerRange.dart <==
import 'package:wowit/model.dart';
import 'package:wowit/sqlService.dart';
import 'common.dart';
import 'methods.dart';

class PickerRange {
  static init() async {
    var ds = await SQLService.execute('sp_dsPickerRange');
    var dtData = ds[0];
    for (var row in dtData) {
      String tableName = Methods.getString(row, 'tableName', defaultValue: "");
      bool isRange = Methods.getBool(row, 'isRange', defaultValue: false);
      if (tableName == "") continue;
      if (isRange) {
        await PickerRange.initDataRange(tableName);
      } else {
        await PickerRange.initDataPicker(tableName);
      }
    }
  }

  static String getDataPicker(List<KeyValue> data, int id,
      {String defaultValue = ""}) {
    for (int i = 0; i < data.length; i++) {
      try {
        if (data[i].valueMember == id) {
          return data[i].displayMember;
        }
      } catch (e) {
        print('getDataPicker ex:' + e.toString());
      }
    }

    return defaultValue;
  }

  static List<KeyValue> getValueDataPicker(String tableName,
      {int parentId = -1}) {
    if (Common.mapPicker.containsKey(tableName)) {
      if (parentId == null || parentId == -1)
        return Common.mapPicker[tableName];
      List<KeyValue> data = Common.mapPicker[tableName];
      List<KeyValue> lst = [];
      for (int i = 0; i < data.length; i++) {
        if (data[i].parentValue == parentId) {
          lst.add(data[i]);
        }
      }
      return lst;
    } else
      SQLService.execute('sp_AddPickerRange',
          params: {'@tableName': tableName});
    return [];
  }

  static Future<List<KeyValue>> initDataPicker(String tableName,
      {bool override = false}) async {
    if (Common.mapPicker.containsKey(tableName) && !override)
      return Common.mapPicker[tableName];
    List<KeyValue> listVal = [];
    try {
      var ds = await SQLService.execute('sp_getValueDataPicker',
          params: {'@tableName': tableName});
      var dtData = ds[0];
      for (var row in dtData) {
        int id = Methods.getInt(row, 'ID', defaultValue: -1);
        int parentId = Methods.getInt(row, 'parentId', defaultValue: -1);
        String title = Methods.getString(row, 'title', defaultValue: "");
        if (id < 0) continue;
        listVal.add(KeyValue(parentId, id, title));
      }
      if (!Common.mapPicker.containsKey(tableName))
        Common.mapPicker[tableName] = listVal;
    } catch (ex) {
      print('[Exception] getValueDataPicker: ' + ex);
    }
    print('getValueDataPicker: ' +
        tableName +
        ' count: ' +
        listVal.length.toString());
    return listVal;
  }

  static Map<int, RangeValue> getValueDataRange(String tableName) {
    if (Common.mapRange.containsKey(tableName)) {
      return Common.mapRange[tableName];
    } else
      SQLService.execute('sp_AddPickerRange',
          params: {'@tableName': tableName});
    return {};
  }

  static Future<Map<int, RangeValue>> initDataRange(String tableName,
      {bool override = false}) async {
    if (Common.mapRange.containsKey(tableName) && !override)
      return Common.mapRange[tableName];
    Map<int, RangeValue> listVal = {};
    try {
      var ds = await SQLService.execute('sp_getValueDataRange',
          params: {'@tableName': tableName});
      var dtData = ds[0];
      for (var row in dtData) {
        int id = Methods.getInt(row, 'ID', defaultValue: -1);
        String title = Methods.getString(row, 'title', defaultValue: "");
        double from = Methods.getDouble(row, 'valFrom', defaultValue: 0);
        double to = Methods.getDouble(row, 'valTo', defaultValue: 0);
        if (id < 0) continue;
        listVal[id] = RangeValue(from, to, title: title);
      }
      if (!Common.mapRange.containsKey(tableName))
        Common.mapRange[tableName] = listVal;
    } catch (ex) {
      print('[Exception] initDataRange: ' + ex);
    }
    print('getValueDataPicker: ' +
        tableName +
        ' count: ' +
        listVal.length.toString());
    return listVal;
  }

  static RangeValue getRangeValueDataPicker(
      Map<int, RangeValue> rangeMap, int id,
      {RangeValue defaultValue = const RangeValue(0, 0)}) {
    return rangeMap[id] ?? defaultValue;
  }
}

==> 0.3.143.tar.gz: lib/pickerRange.dart <==
import 'package:wowit/model.dart';
import 'package:wowit/sqlService.dart';
import 'common.dart';
import 'methods.dart';

class PickerRange {
  static init() async {
    try {
      var ds = await SQLService.execute('sp_dsPickerRange');
      if (ds.length == 0) {
        return;
      }
      var dtData = ds[0];
      for (var row in dtData) {
        String tableName = Methods.getString(row, 'tableName');
        bool isRange = Methods.getBool(row, 'isRange');
        if (tableName == "") continue;
        print("PickerRange init: " + tableName);
        if (isRange) {
          await PickerRange.initDataRange(tableName);
        } else {
          await PickerRange.initDataPicker(tableName);
        }
      }
    } catch (ex) {
      print("PickerRange init exception: " + ex);
    }
  }

  static String getDataPicker(List<KeyValue> data, int id,
      {String defaultValue = ""}) {
    for (int i = 0; i < data.length; i++) {
      try {
        if (data[i].valueMember == id) {
          return data[i].displayMember;
        }
      } catch (e) {
        print('getDataPicker ex:' + e.toString());
      }
    }

    return defaultValue;
  }

  static List<KeyValue> getValueDataPicker(String tableName,
      {int parentId = -1}) {
    if (Common.mapPicker.containsKey(tableName)) {
      if (parentId == null || parentId == -1)
        return Common.mapPicker[tableName];
      List<KeyValue> data = Common.mapPicker[tableName];
      List<KeyValue> lst = [];
      for (int i = 0; i < data.length; i++) {
        if (data[i].parentValue == parentId) {
          lst.add(data[i]);
        }
      }
      return lst;
    } else
      SQLService.execute('sp_AddPickerRange',
          params: {'@tableName': tableName});
    return [];
  }

  static Future<List<KeyValue>> initDataPicker(String tableName,
      {bool override = false}) async {
    if (Common.mapPicker.containsKey(tableName) && !override)
      return Common.mapPicker[tableName];
    List<KeyValue> listVal = [];
    try {
      var ds = await SQLService.execute('sp_getValueDataPicker',
          params: {'@tableName': tableName});
      if (ds.length == 0) return listVal;
      var dtData = ds[0];
      for (var row in dtData) {
        int id = Methods.getInt(row, 'ID', defaultValue: -1);
        int parentId = Methods.getInt(row, 'parentId');
        String title = Methods.getString(row, 'title');
        if (id < 0) continue;
        listVal.add(KeyValue(parentId, id, title));
      }
      if (!Common.mapPicker.containsKey(tableName))
        Common.mapPicker[tableName] = listVal;
    } catch (ex) {
      print('[Exception] getValueDataPicker: ' + ex);
    }
    print('getValueDataPicker: ' +
        tableName +
        ' count: ' +
        listVal.length.toString());
    return listVal;
  }

  static Map<int, RangeValue> getValueDataRange(String tableName) {
    if (Common.mapRange.containsKey(tableName)) {
      return Common.mapRange[tableName];
    } else
      SQLService.execute('sp_AddPickerRange',
          params: {'@tableName': tableName});
    return {};
  }

  static Future<Map<int, RangeValue>> initDataRange(String tableName,
      {bool override = false}) async {
    if (Common.mapRange.containsKey(tableName) && !override)
      return Common.mapRange[tableName];
    Map<int, RangeValue> listVal = {};
    try {
      var ds = await SQLService.execute('sp_getValueDataRange',
          params: {'@tableName': tableName});
      if (ds.length == 0) return listVal;
      var dtData = ds[0];
      for (var row in dtData) {
        int id = Methods.getInt(row, 'ID', defaultValue: -1);
        String title = Methods.getString(row, 'title');
        double from = Methods.getDouble(row, 'valFrom', defaultValue: 0);
        double to = Methods.getDouble(row, 'valTo', defaultValue: 0);
        if (id < 0) continue;
        listVal[id] = RangeValue(from, to, title: title);
      }
      if (!Common.mapRange.containsKey(tableName))
        Common.mapRange[tableName] = listVal;
    } catch (ex) {
      print('[Exception] initDataRange: ' + ex);
    }
    print('getValueDataPicker: ' +
        tableName +
        ' count: ' +
        listVal.length.toString());
    return listVal;
  }

  static RangeValue getRangeValueDataPicker(
      Map<int, RangeValue> rangeMap, int id,
      {RangeValue defaultValue = const RangeValue(0, 0)}) {
    return rangeMap[id] ?? defaultValue;
  }
}
